import { type MenuItemConstructorOptions } from 'electron';
export type ShowAboutWindowOptions = {
    /**
    An absolute path to the app icon.

    Only used on Linux and Windows.
    */
    readonly icon?: string;
    /**
    The copyright text.
    */
    readonly copyright?: string;
    /**
    The URL to the app's website.

    Only used on Linux.
    */
    readonly website?: string;
    /**
    Some additional text if needed.

    Only used on Windows.
    */
    readonly text?: string;
    /**
    Customizable for localization. Used in the menu item label and window title (Windows-only).

    The app name is automatically appended at runtime.

    Only used on Linux and Windows.

    @default 'About'
    */
    readonly title?: string;
};
export type AboutMenuItemOptions = ShowAboutWindowOptions;
/**
Shows an 'About' window. On macOS and Linux, the native 'About' window is shown, and on Windows, a simple custom dialog is shown.
On macOS, the `icon`, `text`, `title`, and `website` options are ignored.

_It will show `Electron` as the app name until you build your app for production._

@param options

@example
```
import {showAboutWindow} from 'electron-util';

showAboutWindow({
    icon: path.join(__dirname, 'static/Icon.png'),
    copyright: 'Copyright © Sindre Sorhus',
    text: 'Some more info.'
});
```
*/
export declare const showAboutWindow: (options: ShowAboutWindowOptions) => void;
/**
Accepts the same options as `.showAboutWindow()`.

@returns A `MenuItemConstructorOptions` that creates a menu item, which shows the about dialog when clicked.

@example
```
import {Menu} from 'electron';
import {aboutMenuItem} from 'electron-util';

const menu = Menu.buildFromTemplate([
    {
        label: 'Help',
        submenu: [
            aboutMenuItem({
                icon: path.join(__dirname, 'static/Icon.png'),
                copyright: 'Copyright © Sindre Sorhus',
                text: 'Some more info.'
            })
        ]
    }
]);

Menu.setApplicationMenu(menu);
*/
export declare const aboutMenuItem: (options?: AboutMenuItemOptions) => MenuItemConstructorOptions;
