import { type Session } from 'electron';
export type SetContentSecurityPolicyOptions = {
    /**
    The session to apply the policy to.

    Default: [`electron.session.defaultSession`](https://electronjs.org/docs/api/session#sessiondefaultsession)
    */
    readonly session?: Session;
};
/**
Set a [Content Security Policy](https://developers.google.com/web/fundamentals/security/csp/) for your app.
Don't forget to [validate the policy](https://csp-evaluator.withgoogle.com) after changes.

@param policy - You can put rules on separate lines, but lines must end in a semicolon.

@example
```
import setContentSecurityPolicy from 'electron-util';

setContentSecurityPolicy(`
    default-src 'none';
    script-src 'self';
    img-src 'self' data:;
    style-src 'self';
    font-src 'self';
    connect-src 'self' https://api.example.com;
    base-uri 'none';
    form-action 'none';
    frame-ancestors 'none';
`);
*/
export declare const setContentSecurityPolicy: (policy: string, options?: SetContentSecurityPolicyOptions) => Promise<void>;
