export type SystemPreferencesMacOsPanes = {
    universalaccess: 'Captioning' | 'Hearing' | 'Keyboard' | 'Media_Descriptions' | 'Mouse' | 'Seeing_Display' | 'Seeing_VoiceOver' | 'Seeing_Zoom' | 'SpeakableItems' | 'Switch';
    security: 'Advanced' | 'FDE' | 'Firewall' | 'General' | 'Privacy' | 'Privacy_Accessibility' | 'Privacy_Advertising'
    /**
        Full Disk Access.
        */
     | 'Privacy_AllFiles' | 'Privacy_Assistive' | 'Privacy_Automation' | 'Privacy_Calendars' | 'Privacy_Camera' | 'Privacy_Contacts' | 'Privacy_DesktopFolder' | 'Privacy_Diagnostics' | 'Privacy_DocumentsFolder' | 'Privacy_DownloadsFolder' | 'Privacy_LocationServices' | 'Privacy_Microphone' | 'Privacy_Photos' | 'Privacy_Reminders' | 'Privacy_ScreenCapture';
    speech: 'Dictation' | 'TTS';
    sharing: 'Internet' | 'Services_ARDService' | 'Services_BluetoothSharing' | 'Services_PersonalFileSharing' | 'Services_PrinterSharing' | 'Services_RemoteAppleEvent' | 'Services_RemoteLogin' | 'Services_ScreenSharing';
};
export type SystemPreferencesWindowsPanes = 
/**
System
*/
'display' | 'sound' | 'notifications' | 'quiethours' | 'powersleep' | 'batterysaver' | 'storagesense' | 'tabletmode' | 'multitasking' | 'project' | 'crossdevice' | 'clipboard' | 'remotedesktop' | 'about'
/**
Devices
*/
 | 'bluetooth' | 'connecteddevices' | 'printers' | 'mousetouchpad' | 'devices-touchpad' | 'typing' | 'wheel' | 'pen' | 'autoplay' | 'usb' | 'mobile-devices'
/**
Network & Internet
*/
 | 'network' | 'network-status' | 'network-cellular' | 'network-wifi' | 'network-wificalling' | 'network-ethernet' | 'network-dialup' | 'network-vpn' | 'network-airplanemode' | 'network-mobilehotspot' | 'nfctransactions' | 'datausage' | 'network-proxy'
/**
Personalization
*/
 | 'personalization' | 'personalization-background' | 'personalization-colors' | 'lockscreen' | 'themes' | 'fonts' | 'personalization-start' | 'taskbar'
/**
Apps
*/
 | 'appsfeatures' | 'optionalfeatures' | 'defaultapps' | 'maps' | 'appsforwebsites' | 'videoplayback' | 'startupapps'
/**
Accounts
*/
 | 'yourinfo' | 'emailandaccounts' | 'signinoptions' | 'workplace' | 'otherusers' | 'sync'
/**
Time & language
*/
 | 'dateandtime' | 'regionformatting' | 'regionlanguage' | 'speech'
/**
Gaming
*/
 | 'gaming-gamebar' | 'gaming-gamedvr' | 'gaming-broadcasting' | 'gaming-gamemode' | 'gaming-xboxnetworking'
/**
Ease of Access
*/
 | 'easeofaccess-display' | 'easeofaccess-cursorandpointersize' | 'easeofaccess-cursor' | 'easeofaccess-magnifier' | 'easeofaccess-colorfilter' | 'easeofaccess-highcontrast' | 'easeofaccess-narrator' | 'easeofaccess-audio' | 'easeofaccess-closedcaptioning' | 'easeofaccess-speechrecognition' | 'easeofaccess-keyboard' | 'easeofaccess-mouse' | 'easeofaccess-eyecontrol'
/**
Search & Cortana
*/
 | 'search-permissions' | 'cortana-windowssearch' | 'cortana' | 'cortana-talktocortana' | 'cortana-permissions'
/**
Privacy
*/
 | 'privacy' | 'privacy-speech' | 'privacy-speechtyping' | 'privacy-feedback' | 'privacy-activityhistory' | 'privacy-location' | 'privacy-webcam' | 'privacy-microphone' | 'privacy-voiceactivation' | 'privacy-notifications' | 'privacy-accountinfo' | 'privacy-contacts' | 'privacy-calendar' | 'privacy-phonecalls' | 'privacy-callhistory' | 'privacy-email' | 'privacy-eyetracker' | 'privacy-tasks' | 'privacy-messaging' | 'privacy-radios' | 'privacy-customdevices' | 'privacy-backgroundapps' | 'privacy-appdiagnostics' | 'privacy-automaticfiledownloads' | 'privacy-documents' | 'privacy-pictures' | 'privacy-videos' | 'privacy-broadfilesystemaccess'
/**
Update & security
*/
 | 'windowsupdate' | 'delivery-optimization' | 'windowsdefender' | 'backup' | 'troubleshoot' | 'recovery' | 'activation' | 'findmydevice' | 'developers' | 'windowsinsider';
/**
Open the System Preferences on macOS.

This method does nothing on other systems.

Optionally provide a pane and section.

@example
```
import {openSystemPreferences} from 'electron-util';

openSystemPreferences();

// or

openSystemPreferences('security', 'Firewall');
```

@param pane - The pane to open.
@param section - The section within that pane.
@returns A Promise that resolves when the preferences window is opened.
*/
export declare const openSystemPreferences: <T extends "display" | "sound" | "notifications" | "quiethours" | "powersleep" | "batterysaver" | "storagesense" | "tabletmode" | "multitasking" | "project" | "crossdevice" | "clipboard" | "remotedesktop" | "about" | "bluetooth" | "connecteddevices" | "printers" | "mousetouchpad" | "devices-touchpad" | "typing" | "wheel" | "pen" | "autoplay" | "usb" | "mobile-devices" | "network" | "network-status" | "network-cellular" | "network-wifi" | "network-wificalling" | "network-ethernet" | "network-dialup" | "network-vpn" | "network-airplanemode" | "network-mobilehotspot" | "nfctransactions" | "datausage" | "network-proxy" | "personalization" | "personalization-background" | "personalization-colors" | "lockscreen" | "themes" | "fonts" | "personalization-start" | "taskbar" | "appsfeatures" | "optionalfeatures" | "defaultapps" | "maps" | "appsforwebsites" | "videoplayback" | "startupapps" | "yourinfo" | "emailandaccounts" | "signinoptions" | "workplace" | "otherusers" | "sync" | "dateandtime" | "regionformatting" | "regionlanguage" | "speech" | "gaming-gamebar" | "gaming-gamedvr" | "gaming-broadcasting" | "gaming-gamemode" | "gaming-xboxnetworking" | "easeofaccess-display" | "easeofaccess-cursorandpointersize" | "easeofaccess-cursor" | "easeofaccess-magnifier" | "easeofaccess-colorfilter" | "easeofaccess-highcontrast" | "easeofaccess-narrator" | "easeofaccess-audio" | "easeofaccess-closedcaptioning" | "easeofaccess-speechrecognition" | "easeofaccess-keyboard" | "easeofaccess-mouse" | "easeofaccess-eyecontrol" | "search-permissions" | "cortana-windowssearch" | "cortana" | "cortana-talktocortana" | "cortana-permissions" | "privacy" | "privacy-speech" | "privacy-speechtyping" | "privacy-feedback" | "privacy-activityhistory" | "privacy-location" | "privacy-webcam" | "privacy-microphone" | "privacy-voiceactivation" | "privacy-notifications" | "privacy-accountinfo" | "privacy-contacts" | "privacy-calendar" | "privacy-phonecalls" | "privacy-callhistory" | "privacy-email" | "privacy-eyetracker" | "privacy-tasks" | "privacy-messaging" | "privacy-radios" | "privacy-customdevices" | "privacy-backgroundapps" | "privacy-appdiagnostics" | "privacy-automaticfiledownloads" | "privacy-documents" | "privacy-pictures" | "privacy-videos" | "privacy-broadfilesystemaccess" | "windowsupdate" | "delivery-optimization" | "windowsdefender" | "backup" | "troubleshoot" | "recovery" | "activation" | "findmydevice" | "developers" | "windowsinsider" | "universalaccess" | "security" | "sharing">(...args: T extends keyof SystemPreferencesMacOsPanes ? [T, SystemPreferencesMacOsPanes[T]] : [T]) => Promise<void>;
